# uvx: pipx for uv

Inspired by:
- [pipx](https://github.com/pypa/pipx)
- [uv](https://github.com/astral-sh/uv)

## Installation

```bash
# one of these ways:
pip install uvx
uv install uvx
pipx install uvx
```

## Usage
```bash
uvx
```

Run `uvx` without any arguments to see all possible subcommands.

## License

`uvx` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Changelog

See `CHANGELOG.md` [on GitHub](https://github.com/robinvandernoord/uvx/blob/master/CHANGELOG.md)